@@ -445,9 +445,7 @@ class Session:
     
     @property
     def platform_json(self) -> PlatformJson:
-        """Platform D1 json on npexp.
-        
-        """
+        """Platform D1 json on npexp."""
         with contextlib.suppress(AttributeError):
             self._platform_json.load_from_existing()
             return self._platform_json
@@ -477,7 +475,7 @@ class Session:
                 time = getattr(self.platform_json, _)
                 if isinstance(time, datetime.datetime):
                     return time
-            logger.warning('Could not find experiment start time in %s: using start of day instead', self.platform_json)
+            logger.debug('Could not find experiment start time in %s: using start of day instead', self.platform_json)
         return datetime.datetime(*self.date.timetuple()[:5])
     
     @cached_property
@@ -494,7 +492,7 @@ class Session:
                 time = getattr(self.platform_json, _)
                 if isinstance(time, datetime.datetime):
                     return time
-            logger.warning('Could not find experiment end time in %s: using end of day instead', self.platform_json)
+            logger.debug('Could not find experiment end time in %s: using end of day instead', self.platform_json)
         return datetime.datetime(*self.date.timetuple()[:5]) + datetime.timedelta(days=1) - datetime.timedelta(seconds=1)
     
     @property
